# Tag Function IDA Pro Plugin

IDA Pro plugin for tagging functions into folders.

## Installation

Assuming you have the [IDA Pro Plugin Manager](https://github.com/williballenthin/idawilli/tree/master/plugins/plugin-manager/), install via pip:

```bash
pip install williballenthin-tag-func-ida-plugin
```

Make sure to use the pip from your IDAPython installation.